..
   Created : 2015-11-04

   @author: Eric Lapouyade

====
base
====
.. automodule:: textops.base
.. currentmodule:: textops

activate_debug
--------------
   .. autofunction:: activate_debug()

add_textop
----------
   .. autofunction:: add_textop

add_textop_iter
---------------
   .. autofunction:: add_textop_iter

dictmerge
---------
   .. autofunction:: dictmerge

dformat
-------
   .. autofunction:: dformat

eformat
-------
   .. autofunction:: eformat

vformat
-------

   Same syntaxe as :meth:`string.Formatter.vformat`

DictExt
-------
   .. autoclass:: DictExt
      :members:

ListExt
-------
   .. autoclass:: ListExt
      :members:

StrExt
------
   .. autoclass:: StrExt
      :members:

TextOp
------
   .. autoclass:: TextOp
      :members:

BytesExt
----------
   .. autoclass:: BytesExt
      :members:

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

